import axios, { AxiosInstance, AxiosRequestConfig, AxiosResponse } from 'axios';
// import { useRouter } from 'vue-router';
import { ElMessage } from 'element-plus';
import { IUnknowObject } from '@/types';

interface IResponsePramas extends IUnknowObject {
  Ret: number;
  Msg: string;
}

const baseURL = import.meta.env.VITE_BASEURL;


const request: AxiosInstance = axios.create({
  baseURL,
  timeout:0
});

// 请求拦截器
request.interceptors.request.use(
  (config) => {
    let token: string = localStorage.getItem('token') ?? '';
    if (token) config.headers.Authorization = token;
    return config;
  },
  (error) => {
    return Promise.reject(error);
  }
);

// 响应拦截器
request.interceptors.response.use(
  (response: AxiosResponse) => {
    let code: number = response.data.Ret;
    if (code === 403) {
      ElMessage.error(response.data.Msg);
      return;
    }
    if (code == 40001 || code == 408) {
      // router.replace('/login')
      ElMessage.error(response.data.Msg);
      return;
    }
    return Promise.resolve(response.data);
  },
  (error) => {
    ElMessage.error('网络异常');
    return Promise.reject(error);
  }
);

const get = (url: string, params?: any):Promise<IResponsePramas> =>
  request.get(url, { params });
const post = (
  url: string,
  params: any,
  config?: AxiosRequestConfig
):Promise<IResponsePramas> => request.post(url, params, config);

export { get, post };

export default request;
