import axios, { AxiosInstance, AxiosRequestConfig, AxiosResponse } from 'axios';
// import { useRouter } from 'vue-router';
import { ElMessage } from 'element-plus';
import { IUnknowObject } from '@/types';
import CryptoJS from './crypto.js'

interface IResponsePramas extends IUnknowObject {
  code: number;
  msg: string;
}

const baseURL = import.meta.env.VITE_HZYB_BASEURL;


const request: AxiosInstance = axios.create({
  baseURL,
  timeout:0
});

// 请求拦截器
request.interceptors.request.use(
  (config) => {
    return config;
  },
  (error) => {
    return Promise.reject(error);
  }
);

// 响应拦截器
request.interceptors.response.use(
  (response: AxiosResponse) => {
    let data
    if(import.meta.env.MODE==='production'){
      data=JSON.parse(CryptoJS.Des3Decrypt(response.data));//解密
    }else{
      data=response.data
    }
    return Promise.resolve(data);
  },
  (error) => {
    ElMessage.error('网络异常');
    return Promise.reject(error);
  }
);

const get = (url: string, params?: any):Promise<IResponsePramas> =>
  request.get(url, { params });
const post = (
  url: string,
  params: any,
  config?: AxiosRequestConfig
):Promise<IResponsePramas> => request.post(url, params, config);

export { get, post };

export default request;
